@@ -39,16 +39,7 @@ impl AsyncReaderBuilder {
     ///     Ok(())
     /// }
     /// ```
-    pub fn create_reader<R: io::AsyncRead + std::marker::Unpin>(&self, rdr: R) -> AsyncReader<R> {
-        AsyncReader::new(self, rdr)
-    }
-    
-    /// Build a CSV parser from this configuration that reads data from `rdr`.
-    #[deprecated(
-        since = "1.0.1",
-        note = "Please use AsyncReaderBuilder::create_reader function instead"
-    )]
-    pub fn from_reader<R: io::AsyncRead + std::marker::Unpin>(&self, rdr: R) -> AsyncReader<R> {
+    pub fn create_reader<R: io::AsyncRead + Unpin + Send + Sync>(&self, rdr: R) -> AsyncReader<R> {
         AsyncReader::new(self, rdr)
     }
 }
@@ -80,7 +71,7 @@ impl AsyncReaderBuilder {
 /// ";
 ///     let mut rdr = AsyncReaderBuilder::new()
 ///         .delimiter(b';')
-///         .from_reader(data.as_bytes());
+///         .create_reader(data.as_bytes());
 ///
 ///     let mut records = rdr.records();
 ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
@@ -129,7 +120,7 @@ pub struct AsyncReader<R>(AsyncReaderImpl<R>);
 
 impl<'r, R> AsyncReader<R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r,
+    R: io::AsyncRead + Unpin + Send + Sync + 'r,
 {
     /// Create a new CSV reader given a builder and a source of underlying
     /// bytes.
