@@ -7,7 +7,7 @@ cfg_if::cfg_if! {
 if #[cfg(feature = "tokio")] {
     use std::io::SeekFrom;
     use tokio::io::{self, AsyncBufRead};
-    use tokio::stream::Stream;
+    use tokio_stream::Stream;
 } else {
     use futures::io::{self, AsyncBufRead, AsyncSeekExt};
     use futures::stream::Stream;
@@ -93,7 +93,7 @@ impl AsyncReaderBuilder {
     /// Boston,United States,4628910
     /// Concord,United States,42695
     /// ";
-    ///     let mut rdr = AsyncReaderBuilder::new().from_reader(data.as_bytes());
+    ///     let mut rdr = AsyncReaderBuilder::new().create_reader(data.as_bytes());
     ///
     ///     let records = rdr
     ///         .records()
@@ -109,15 +109,6 @@ impl AsyncReaderBuilder {
     pub fn new() -> AsyncReaderBuilder {
         AsyncReaderBuilder::default()
     }
-    
-    /// Returns csv_core Builder reference.
-    #[deprecated(
-        since = "1.0.1",
-        note = "This getter is no longer needed and will be removed"
-    )]
-    pub fn get_core_builder_ref(&self) -> &Box<CoreReaderBuilder> {
-        &self.builder
-    }
 
     /// The field delimiter to use when parsing CSV.
     ///
@@ -138,7 +129,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .delimiter(b';')
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///
     ///     let records = rdr
     ///         .records()
@@ -153,15 +144,6 @@ impl AsyncReaderBuilder {
         self.builder.delimiter(delimiter);
         self
     }
-    
-    /// Returns information if read file has headers.
-    #[deprecated(
-        since = "1.0.1",
-        note = "This getter is no longer needed and will be removed"
-    )]
-    pub fn get_headers_presence(&self) -> bool {
-        self.has_headers
-    }
 
     /// Whether to treat the first row as a special header row.
     ///
@@ -191,7 +173,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .has_headers(false)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut iter = rdr.records();
     ///
     ///     // Read the first record.
@@ -208,15 +190,6 @@ impl AsyncReaderBuilder {
         self.has_headers = yes;
         self
     }
-    
-    /// Returns information if read file has headers.
-    #[deprecated(
-        since = "1.0.1",
-        note = "This getter is no longer needed and will be removed"
-    )]
-    pub fn is_flexible(&self) -> bool {
-        self.flexible
-    }
 
     /// Whether the number of fields in records is allowed to change or not.
     ///
@@ -242,7 +215,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .flexible(true)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "United States"]);
     ///     Ok(())
@@ -269,7 +242,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .flexible(false)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///
     ///     let mut records = rdr.records();
     ///     match records.next().await {
@@ -302,17 +275,11 @@ impl AsyncReaderBuilder {
         self
     }
     
-    /// Returns information if read file has headers.
-    #[deprecated(
-        since = "1.0.1",
-        note = "This getter is no longer needed and will be removed"
-    )]
-    pub fn get_trim_option(&self) -> Trim {
-        self.trim
-    }
-    
     /// If set, CSV records' stream will end when first i/o error happens. 
-    /// Otherwise it will continue trying to read from underlying reader.
+    /// Otherwise CSV reader will continue trying to read from underlying reader.
+    /// For sample, please see unit test `behavior_on_io_errors` in following
+    /// [source file](https://github.com/gwierzchowski/csv-async/blob/master/src/async_readers/ardr_futures.rs).
+    /// 
     /// By default this option is set.
     pub fn end_on_io_error(&mut self, yes: bool) -> &mut AsyncReaderBuilder {
         self.end_on_io_error = yes;
@@ -355,7 +322,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .trim(Trim::All)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let records = rdr
     ///         .records()
     ///         .map(Result::unwrap)
@@ -390,7 +357,7 @@ impl AsyncReaderBuilder {
     ///     let data = "city,country,pop$Boston,United States,4628910";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .terminator(Terminator::Any(b'$'))
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut iter = rdr.records();
     ///     assert_eq!(iter.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
     ///     assert!(iter.next().await.is_none());
@@ -421,7 +388,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .quote(b'\'')
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut iter = rdr.records();
     ///     assert_eq!(iter.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
     ///     assert!(iter.next().await.is_none());
@@ -455,7 +422,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .escape(Some(b'\\'))
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "The \"United\" States", "4628910"]);
     ///     Ok(())
@@ -486,7 +453,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .double_quote(false)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "The \"United\"\" States\"", "4628910"]);
     ///     Ok(())
@@ -517,7 +484,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .quoting(false)
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "\"The United States", "4628910"]);
     ///     Ok(())
@@ -551,7 +518,7 @@ impl AsyncReaderBuilder {
     /// ";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .comment(Some(b'#'))
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
     ///     assert!(records.next().await.is_none());
@@ -582,7 +549,7 @@ impl AsyncReaderBuilder {
     /// city\x1Fcountry\x1Fpop\x1EBoston\x1FUnited States\x1F4628910";
     ///     let mut rdr = AsyncReaderBuilder::new()
     ///         .ascii()
-    ///         .from_reader(data.as_bytes());
+    ///         .create_reader(data.as_bytes());
     ///     let mut records = rdr.byte_records();
     ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
     ///     assert!(records.next().await.is_none());
@@ -593,15 +560,6 @@ impl AsyncReaderBuilder {
         self.builder.ascii();
         self
     }
-    
-    /// Returns buffer capacity.
-    #[deprecated(
-        since = "1.0.1",
-        note = "This getter is no longer needed and will be removed"
-    )]
-    pub fn get_buffer_capacity(&self) -> usize {
-        self.capacity
-    }
 
     /// Set the capacity (in bytes) of the buffer used in the CSV reader.
     /// This defaults to a reasonable setting.
@@ -764,7 +722,7 @@ impl<R: AsyncBufRead + ?Sized + Unpin> Future for FillBuf<'_, R> {
 
 impl<'r, R> AsyncReaderImpl<R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r,
+    R: io::AsyncRead + Unpin + 'r,
 {
     /// Create a new CSV reader given a builder and a source of underlying
     /// bytes.
@@ -1012,7 +970,7 @@ where
 }
 
 #[cfg(not(feature = "tokio"))]
-impl<R: io::AsyncRead + io::AsyncSeek + std::marker::Unpin> AsyncReaderImpl<R> {
+impl<R: io::AsyncRead + io::AsyncSeek + Unpin> AsyncReaderImpl<R> {
     /// Seeks the underlying reader to the position given.
     ///
     pub async fn seek(&mut self, pos: Position) -> Result<()> {
@@ -1049,7 +1007,7 @@ impl<R: io::AsyncRead + io::AsyncSeek + std::marker::Unpin> AsyncReaderImpl<R> {
 
 #[cfg(feature = "tokio")]
 #[allow(dead_code)]
-impl<R: io::AsyncRead + io::AsyncSeek + std::marker::Unpin> AsyncReaderImpl<R> {
+impl<R: io::AsyncRead + io::AsyncSeek + Unpin> AsyncReaderImpl<R> {
     /// Attempts to seek to an offset, in bytes, in a stream.
     ///
     /// If this function returns successfully, then the job has been submitted.
@@ -1089,7 +1047,7 @@ async fn read_record_borrowed<'r, R>(
     mut rec: StringRecord,
 ) -> (Option<Result<StringRecord>>, &'r mut AsyncReaderImpl<R>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let result = match rdr.read_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1106,7 +1064,7 @@ where
 /// CSV `Reader`.
 pub struct StringRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fut: Option<
         Pin<
@@ -1117,7 +1075,7 @@ where
                             &'r mut AsyncReaderImpl<R>,
                             StringRecord,
                         ),
-                    > + 'r,
+                    > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1125,7 +1083,7 @@ where
 
 impl<'r, R> StringRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fn new(rdr: &'r mut AsyncReaderImpl<R>) -> Self {
         Self {
@@ -1139,7 +1097,7 @@ where
 
 impl<'r, R> Stream for StringRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     type Item = Result<StringRecord>;
 
@@ -1172,7 +1130,7 @@ async fn read_record<R>(
     mut rec: StringRecord,
 ) -> (Option<Result<StringRecord>>, AsyncReaderImpl<R>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let result = match rdr.read_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1186,7 +1144,7 @@ where
 /// An owned stream of records as strings.
 pub struct StringRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fut: Option<
         Pin<
@@ -1197,7 +1155,7 @@ where
                         AsyncReaderImpl<R>,
                         StringRecord,
                     ),
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1205,7 +1163,7 @@ where
 
 impl<'r, R> StringRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     fn new(rdr: AsyncReaderImpl<R>) -> Self {
         Self {
@@ -1219,7 +1177,7 @@ where
 
 impl<'r, R> Stream for StringRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     type Item = Result<StringRecord>;
 
@@ -1251,7 +1209,7 @@ async fn read_byte_record_borrowed<'r, R>(
     mut rec: ByteRecord,
 ) -> (Option<Result<ByteRecord>>, &'r mut AsyncReaderImpl<R>, ByteRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin,
+    R: io::AsyncRead + Unpin,
 {
     let result = match rdr.read_byte_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1268,7 +1226,7 @@ where
 /// CSV `Reader`.
 pub struct ByteRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin,
+    R: io::AsyncRead + Unpin + Send + Sync,
 {
     fut: Option<
         Pin<
@@ -1279,7 +1237,7 @@ where
                             &'r mut AsyncReaderImpl<R>,
                             ByteRecord,
                         ),
-                    > + 'r,
+                    > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1287,7 +1245,7 @@ where
 
 impl<'r, R> ByteRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r,
+    R: io::AsyncRead + Unpin + Send + Sync + 'r,
 {
     fn new(rdr: &'r mut AsyncReaderImpl<R>) -> Self {
         Self {
@@ -1301,7 +1259,7 @@ where
 
 impl<'r, R> Stream for ByteRecordsStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin,
+    R: io::AsyncRead + Send + Sync + Unpin,
 {
     type Item = Result<ByteRecord>;
 
@@ -1334,7 +1292,7 @@ async fn read_byte_record<R>(
     mut rec: ByteRecord,
 ) -> (Option<Result<ByteRecord>>, AsyncReaderImpl<R>, ByteRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let result = match rdr.read_byte_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1348,7 +1306,7 @@ where
 /// An owned stream of records as raw bytes.
 pub struct ByteRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fut: Option<
         Pin<
@@ -1359,7 +1317,7 @@ where
                         AsyncReaderImpl<R>,
                         ByteRecord,
                     ),
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1367,7 +1325,7 @@ where
 
 impl<'r, R> ByteRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Send + Sync + Unpin + 'r
 {
     fn new(rdr: AsyncReaderImpl<R>) -> Self {
         Self {
@@ -1381,7 +1339,7 @@ where
 
 impl<'r, R> Stream for ByteRecordsIntoStream<'r, R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Send + Sync + Unpin + 'r
 {
     type Item = Result<ByteRecord>;
 
@@ -1417,7 +1375,7 @@ async fn deserialize_record_borrowed<'r, R, D: DeserializeOwned>(
     mut rec: StringRecord,
 ) -> (Option<Result<D>>, &'r mut AsyncReaderImpl<R>, Option<StringRecord>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let result = match rdr.read_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1434,7 +1392,7 @@ where
 /// type, and `D` refers to the type that this stream will deserialize a record into.
 pub struct DeserializeRecordsStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     header_fut: Option<
         Pin<
@@ -1444,7 +1402,7 @@ where
                         Result<StringRecord>,
                         &'r mut AsyncReaderImpl<R>,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1458,7 +1416,7 @@ where
                         Option<StringRecord>,
                         StringRecord,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1466,7 +1424,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> DeserializeRecordsStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fn new(rdr: &'r mut AsyncReaderImpl<R>) -> Self {
         let has_headers = rdr.has_headers();
@@ -1490,7 +1448,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> Stream for DeserializeRecordsStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     type Item = Result<D>;
 
@@ -1544,7 +1502,7 @@ async fn deserialize_record_with_pos_borrowed<'r, R, D: DeserializeOwned>(
     mut rec: StringRecord,
 ) -> (Option<Result<D>>, Position, &'r mut AsyncReaderImpl<R>, Option<StringRecord>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let pos = rdr.position().clone();
     let result = match rdr.read_record(&mut rec).await {
@@ -1562,7 +1520,7 @@ where
 /// type, and `D` refers to the type that this stream will deserialize a record into.
 pub struct DeserializeRecordsStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     header_fut: Option<
         Pin<
@@ -1572,7 +1530,7 @@ where
                         Result<StringRecord>,
                         &'r mut AsyncReaderImpl<R>,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1587,7 +1545,7 @@ where
                         Option<StringRecord>,
                         StringRecord,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1595,7 +1553,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> DeserializeRecordsStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     fn new(rdr: &'r mut AsyncReaderImpl<R>) -> Self {
         let has_headers = rdr.has_headers();
@@ -1619,7 +1577,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> Stream for DeserializeRecordsStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     type Item = (Result<D>, Position);
 
@@ -1675,7 +1633,7 @@ async fn deserialize_record<R, D: DeserializeOwned>(
     mut rec: StringRecord,
 ) -> (Option<Result<D>>, AsyncReaderImpl<R>, Option<StringRecord>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let result = match rdr.read_record(&mut rec).await {
         Err(err) => Some(Err(err)),
@@ -1692,7 +1650,7 @@ where
 /// type, and `D` refers to the type that this stream will deserialize a record into.
 pub struct DeserializeRecordsIntoStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync 
 {
     header_fut: Option<
         Pin<
@@ -1702,7 +1660,7 @@ where
                         Result<StringRecord>,
                         AsyncReaderImpl<R>,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1716,7 +1674,7 @@ where
                         Option<StringRecord>,
                         StringRecord,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1724,7 +1682,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> DeserializeRecordsIntoStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     fn new(mut rdr: AsyncReaderImpl<R>) -> Self {
         let has_headers = rdr.has_headers();
@@ -1748,7 +1706,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> Stream for DeserializeRecordsIntoStream<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     type Item = Result<D>;
 
@@ -1802,7 +1760,7 @@ async fn deserialize_record_with_pos<R, D: DeserializeOwned>(
     mut rec: StringRecord,
 ) -> (Option<Result<D>>, Position, AsyncReaderImpl<R>, Option<StringRecord>, StringRecord)
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin
 {
     let pos = rdr.position().clone();
     let result = match rdr.read_record(&mut rec).await {
@@ -1820,7 +1778,7 @@ where
 /// type, and `D` refers to the type that this stream will deserialize a record into.
 pub struct DeserializeRecordsIntoStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin
+    R: io::AsyncRead + Unpin + Send + Sync
 {
     header_fut: Option<
         Pin<
@@ -1830,7 +1788,7 @@ where
                         Result<StringRecord>,
                         AsyncReaderImpl<R>,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1845,7 +1803,7 @@ where
                         Option<StringRecord>,
                         StringRecord,
                     )
-                > + 'r,
+                > + Send + Sync + 'r,
             >,
         >,
     >,
@@ -1853,7 +1811,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> DeserializeRecordsIntoStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     fn new(mut rdr: AsyncReaderImpl<R>) -> Self {
         let has_headers = rdr.has_headers();
@@ -1877,7 +1835,7 @@ where
 
 impl<'r, R, D: DeserializeOwned + 'r> Stream for DeserializeRecordsIntoStreamPos<'r, R, D>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r
+    R: io::AsyncRead + Unpin + Send + Sync + 'r
 {
     type Item = (Result<D>, Position);
 
